==> vod-api-model-1.0.0-sources.jar: com/valor/vod/api/model/user/UserInfoDO.java <==
package com.valor.vod.api.model.user;

import com.valor.vod.api.model.common.AbstractPrintable;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * File        :
 * Description :
 * Author      : Frank
 * Created     : 2015/10/4
 */
public class UserInfoDO extends AbstractPrintable {

    private String did;    //设备id
    private Long uid;    //用户id
    private long accountId = 0;
    private int accountType = 0;
    @Deprecated
    private Long props;  //用户属性
    private EUserGroup group;  //用户组
    private int userStatus; //用户状态
    @Deprecated
    private int minimumSupportVersion;    //客户端最低支持版本
    @Deprecated
    private int isSupportVersion;         //是否是支持版本

    private int trial = 0;
    private Map<String, String> plan = new HashMap<>();
    @Deprecated
    private int installType = 0;

    private Map<String, String> userProperites = null;

    private Map<String, Object> dataMap = new HashMap<>();

    private UserLocationDo location = null;
    private List<UserBizDo> bizs = new ArrayList<UserBizDo>();
    private UserPlayModeDo playMode = null;
    private UserAccountDo userAccount = null;

    private List<SubAccountDo> subAccounts = new ArrayList<SubAccountDo>();
    private List<SessionInfoDo> clientInfo;

    private List<LoginMethodDO> loginMethods;

    @Deprecated
    private int preInstall = 0;
    @Deprecated
    private int prePaid = 0;
    private int accountLoginType = EAccountLoginType.DEVICE.ordinal();

    private int deviceLimit = 0;
    private int renewal = 0;

    private int userType = -1;
    private String subscribeEmail = "";

    public int getRenewal() {
        return renewal;
    }

    public void setRenewal(int renewal) {
        this.renewal = renewal;
    }

    public String getDid() {
        return did;
    }

    public void setDid(String did) {
        this.did = did;
    }

    public Long getUid() {
        return uid;
    }

    public void setUid(Long uid) {
        this.uid = uid;
    }

    public long getAccountId() {
        return accountId;
    }

    public void setAccountId(long accountId) {
        this.accountId = accountId;
    }

    public int getAccountType() {
        return accountType;
    }

    public void setAccountType(int accountType) {
        this.accountType = accountType;
    }

    public Long getProps() {
        return props;
    }

    public void setProps(Long props) {
        this.props = props;
    }

    public EUserGroup getGroup() {
        return group;
    }

    public void setGroup(EUserGroup group) {
        this.group = group;
    }

    public int getUserStatus() {
        return userStatus;
    }

    public void setUserStatus(int userStatus) {
        this.userStatus = userStatus;
    }

    public int getMinimumSupportVersion() {
        return minimumSupportVersion;
    }

    public void setMinimumSupportVersion(int minimumSupportVersion) {
        this.minimumSupportVersion = minimumSupportVersion;
    }

    public int getIsSupportVersion() {
        return isSupportVersion;
    }

    public void setIsSupportVersion(int isSupportVersion) {
        this.isSupportVersion = isSupportVersion;
    }

    public int getTrial() {
        return trial;
    }

    public void setTrial(int trial) {
        this.trial = trial;
    }

    public Map<String, String> getPlan() {
        return plan;
    }

    public void setPlan(Map<String, String> plan) {
        this.plan = plan;
    }

    public int getInstallType() {
        return installType;
    }

    public void setInstallType(int installType) {
        this.installType = installType;
    }

    public Map<String, String> getUserProperites() {
        return userProperites;
    }

    public void setUserProperites(Map<String, String> userProperites) {
        this.userProperites = userProperites;
    }

    public UserLocationDo getLocation() {
        return location;
    }

    public void setLocation(UserLocationDo location) {
        this.location = location;
    }

    public List<UserBizDo> getBizs() {
        return bizs;
    }

    public void setBizs(List<UserBizDo> bizs) {
        this.bizs = bizs;
    }

    public UserPlayModeDo getPlayMode() {
        return playMode;
    }

    public void setPlayMode(UserPlayModeDo playMode) {
        this.playMode = playMode;
    }

    public UserAccountDo getUserAccount() {
        return userAccount;
    }

    public void setUserAccount(UserAccountDo userAccount) {
        this.userAccount = userAccount;
    }

    public List<SubAccountDo> getSubAccounts() {
        return subAccounts;
    }

    public void setSubAccounts(List<SubAccountDo> subAccounts) {
        this.subAccounts = subAccounts;
    }

    public List<SessionInfoDo> getClientInfo() {
        return clientInfo;
    }

    public void setClientInfo(List<SessionInfoDo> clientInfo) {
        this.clientInfo = clientInfo;
    }

    public List<LoginMethodDO> getLoginMethods() {
        return loginMethods;
    }

    public void setLoginMethods(List<LoginMethodDO> loginMethods) {
        this.loginMethods = loginMethods;
    }

    public int getPreInstall() {
        return preInstall;
    }

    public void setPreInstall(int preInstall) {
        this.preInstall = preInstall;
    }

    public int getPrePaid() {
        return prePaid;
    }

    public void setPrePaid(int prePaid) {
        this.prePaid = prePaid;
    }

    public int getDeviceLimit() {
        return deviceLimit;
    }

    public void setDeviceLimit(int deviceLimit) {
        this.deviceLimit = deviceLimit;
    }

    public int getAccountLoginType() {
        return accountLoginType;
    }

    public void setAccountLoginType(int accountLoginType) {
        this.accountLoginType = accountLoginType;
    }


    public int getUserType() {
        return userType;
    }

    public void setUserType(int userType) {
        this.userType = userType;
    }

    public Map<String, Object> getDataMap() {
        return dataMap;
    }

    public void setDataMap(Map<String, Object> dataMap) {
        this.dataMap = dataMap;
    }

    public String getSubscribeEmail() {
        return subscribeEmail;
    }

    public void setSubscribeEmail(String subscribeEmail) {
        this.subscribeEmail = subscribeEmail;
    }
}

==> vod-api-model-1.0.2-sources.jar: com/valor/vod/api/model/user/UserInfoDO.java <==
package com.valor.vod.api.model.user;

import com.valor.vod.api.model.common.AbstractPrintable;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/** File : Description : Author : Frank Created : 2015/10/4 */
public class UserInfoDO extends AbstractPrintable {

    private String did; // 设备id
    private Long uid; // 用户id
    private long accountId = 0;
    private int accountType = 0;
    @Deprecated private Long props; // 用户属性
    private EUserGroup group; // 用户组
    private int userStatus; // 用户状态
    @Deprecated private int minimumSupportVersion; // 客户端最低支持版本
    @Deprecated private int isSupportVersion; // 是否是支持版本

    private int trial = 0;
    private Map<String, String> plan = new HashMap<>();
    @Deprecated private int installType = 0;

    private Map<String, String> userProperites = null;

    private Map<String, Object> dataMap = new HashMap<>();

    private UserLocationDo location = null;
    private List<UserBizDo> bizs = new ArrayList<UserBizDo>();
    private UserPlayModeDo playMode = null;
    private UserAccountDo userAccount = null;

    private List<SubAccountDo> subAccounts = new ArrayList<SubAccountDo>();
    private List<SessionInfoDo> clientInfo;

    private List<LoginMethodDO> loginMethods;

    @Deprecated private int preInstall = 0;
    @Deprecated private int prePaid = 0;
    private int accountLoginType = EAccountLoginType.DEVICE.ordinal();

    private int deviceLimit = 0;
    private int renewal = 0;

    private int userType = -1;
    private String subscribeEmail = "";

    /**
     * 渠道ID
     *
     * @mock 1000100
     */
    private Long vendorId;

    /**
     * 渠道品牌
     *
     * @mock BTV
     */
    private String vendorBrand;

    public int getRenewal() {
        return renewal;
    }

    public void setRenewal(int renewal) {
        this.renewal = renewal;
    }

    public String getDid() {
        return did;
    }

    public void setDid(String did) {
        this.did = did;
    }

    public Long getUid() {
        return uid;
    }

    public void setUid(Long uid) {
        this.uid = uid;
    }

    public long getAccountId() {
        return accountId;
    }

    public void setAccountId(long accountId) {
        this.accountId = accountId;
    }

    public int getAccountType() {
        return accountType;
    }

    public void setAccountType(int accountType) {
        this.accountType = accountType;
    }

    public Long getProps() {
        return props;
    }

    public void setProps(Long props) {
        this.props = props;
    }

    public EUserGroup getGroup() {
        return group;
    }

    public void setGroup(EUserGroup group) {
        this.group = group;
    }

    public int getUserStatus() {
        return userStatus;
    }

    public void setUserStatus(int userStatus) {
        this.userStatus = userStatus;
    }

    public int getMinimumSupportVersion() {
        return minimumSupportVersion;
    }

    public void setMinimumSupportVersion(int minimumSupportVersion) {
        this.minimumSupportVersion = minimumSupportVersion;
    }

    public int getIsSupportVersion() {
        return isSupportVersion;
    }

    public void setIsSupportVersion(int isSupportVersion) {
        this.isSupportVersion = isSupportVersion;
    }

    public int getTrial() {
        return trial;
    }

    public void setTrial(int trial) {
        this.trial = trial;
    }

    public Map<String, String> getPlan() {
        return plan;
    }

    public void setPlan(Map<String, String> plan) {
        this.plan = plan;
    }

    public int getInstallType() {
        return installType;
    }

    public void setInstallType(int installType) {
        this.installType = installType;
    }

    public Map<String, String> getUserProperites() {
        return userProperites;
    }

    public void setUserProperites(Map<String, String> userProperites) {
        this.userProperites = userProperites;
    }

    public UserLocationDo getLocation() {
        return location;
    }

    public void setLocation(UserLocationDo location) {
        this.location = location;
    }

    public List<UserBizDo> getBizs() {
        return bizs;
    }

    public void setBizs(List<UserBizDo> bizs) {
        this.bizs = bizs;
    }

    public UserPlayModeDo getPlayMode() {
        return playMode;
    }

    public void setPlayMode(UserPlayModeDo playMode) {
        this.playMode = playMode;
    }

    public UserAccountDo getUserAccount() {
        return userAccount;
    }

    public void setUserAccount(UserAccountDo userAccount) {
        this.userAccount = userAccount;
    }

    public List<SubAccountDo> getSubAccounts() {
        return subAccounts;
    }

    public void setSubAccounts(List<SubAccountDo> subAccounts) {
        this.subAccounts = subAccounts;
    }

    public List<SessionInfoDo> getClientInfo() {
        return clientInfo;
    }

    public void setClientInfo(List<SessionInfoDo> clientInfo) {
        this.clientInfo = clientInfo;
    }

    public List<LoginMethodDO> getLoginMethods() {
        return loginMethods;
    }

    public void setLoginMethods(List<LoginMethodDO> loginMethods) {
        this.loginMethods = loginMethods;
    }

    public int getPreInstall() {
        return preInstall;
    }

    public void setPreInstall(int preInstall) {
        this.preInstall = preInstall;
    }

    public int getPrePaid() {
        return prePaid;
    }

    public void setPrePaid(int prePaid) {
        this.prePaid = prePaid;
    }

    public int getDeviceLimit() {
        return deviceLimit;
    }

    public void setDeviceLimit(int deviceLimit) {
        this.deviceLimit = deviceLimit;
    }

    public int getAccountLoginType() {
        return accountLoginType;
    }

    public void setAccountLoginType(int accountLoginType) {
        this.accountLoginType = accountLoginType;
    }

    public int getUserType() {
        return userType;
    }

    public void setUserType(int userType) {
        this.userType = userType;
    }

    public Map<String, Object> getDataMap() {
        return dataMap;
    }

    public void setDataMap(Map<String, Object> dataMap) {
        this.dataMap = dataMap;
    }

    public String getSubscribeEmail() {
        return subscribeEmail;
    }

    public void setSubscribeEmail(String subscribeEmail) {
        this.subscribeEmail = subscribeEmail;
    }

    public Long getVendorId() {
        return vendorId;
    }

    public void setVendorId(Long vendorId) {
        this.vendorId = vendorId;
    }

    public String getVendorBrand() {
        return vendorBrand;
    }

    public void setVendorBrand(String vendorBrand) {
        this.vendorBrand = vendorBrand;
    }
}
